src/eric7/WebBrowser/Passwords/PasswordManager.py

branch
eric7
changeset 9971
773ad1f1ed22
parent 9653
e67609152c5e
child 10180
3a595df36c9a
--- a/src/eric7/WebBrowser/Passwords/PasswordManager.py	Tue Apr 04 17:26:54 2023 +0200
+++ b/src/eric7/WebBrowser/Passwords/PasswordManager.py	Wed Apr 05 11:58:22 2023 +0200
@@ -383,12 +383,12 @@
         script = Scripts.completeFormData(postData)
         page.runJavaScript(script, WebBrowserPage.SafeJsWorld)
 
-    def masterPasswordChanged(self, oldPassword, newPassword):
+    def mainPasswordChanged(self, oldPassword, newPassword):
         """
         Public slot to handle the change of the master password.
 
-        @param oldPassword current master password (string)
-        @param newPassword new master password (string)
+        @param oldPassword current main password (string)
+        @param newPassword new main password (string)
         """
         if not self.__loaded:
             self.__load()
@@ -383,12 +383,12 @@
         """
-        Public slot to handle the change of the master password.
+        Public slot to handle the change of the main password.
 

eric ide

mercurial